@@ -14,7 +14,7 @@ from optparse import OptionParser
 from subprocess import Popen, PIPE
 from difflib import unified_diff
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 
 pep8bin = 'pep8'
@@ -31,9 +31,12 @@ class FixPEP8(object):
     - e201
     - e203
     - e211
+    - e225
     - e231
+    - e251
     - e261
     - e262
+    - e301
     - e302
     - e303
     - e401
@@ -95,12 +98,13 @@ class FixPEP8(object):
         filename = tmp[0]
         line = int(tmp[1])
         column = int(tmp[2])
-        info = " ".join(tmp[3:])
+        info = " ".join(result.split()[1:])
         pep8id = info.lstrip().split()[0]
         return dict(id=pep8id, filename=filename, line=line,
                     column=column, info=info)
 
     def _execute_pep8(self, targetfile):
+        """execute pep8 via subprocess.Popen."""
         paths = os.environ['PATH'].split(':')
         paths.reverse()
         for path in paths:
@@ -136,6 +140,16 @@ class FixPEP8(object):
         self._fix_source()
         return "".join(self.source)
 
+    #def fix_e101(self, result):
+    #    target = self.source[result['line'] - 1]
+    #    offset = result['column'] - 1
+    #    if target[offset] == '\t':
+    #        fixed = self.indent_word + target[offset + 1:]
+    #    else:
+    #        # FIXME: not implement
+    #        fixed = target
+    #    self.source[result['line'] - 1] = fixed
+
     def fix_e201(self, result):
         self._fix_whitespace(result, r"(\( )", "(")
 
@@ -145,6 +159,12 @@ class FixPEP8(object):
     def fix_e211(self, result):
         self._fix_whitespace(result, r"( \()", "(")
 
+    def fix_e221(self, result):
+        target = self.source[result['line'] - 1]
+        c = result['column'] + 1
+        fixed = re.sub(r'\s+', ' ', target[c::-1], 1)[::-1] + target[c + 1:]
+        self.source[result['line'] - 1] = fixed
+
     def fix_e225(self, result):
         target = self.source[result['line'] - 1]
         offset = result['column']
@@ -161,14 +181,21 @@ class FixPEP8(object):
 
     def fix_e231(self, result):
         target = self.source[result['line'] - 1]
+        target_char = result['info'].split()[-1][1]
         fixed = ""
         fixed_end = 0
-        for i in re.finditer(",\S", target):
-            fixed += target[fixed_end:i.start()] + ", "
+        for i in re.finditer("%s\S" % target_char, target):
+            fixed += target[fixed_end:i.start()] + "%s " % target_char
             fixed_end = i.end() - 1
         fixed += target[fixed_end:]
         self.source[result['line'] - 1] = fixed
 
+    def fix_e251(self, result):
+        target = self.source[result['line'] - 1]
+        c = result['column'] - 1
+        fixed = target[:c] + re.sub(r'\s*=\s*', '=', target[c:], 1)
+        self.source[result['line'] - 1] = fixed
+
     def fix_e261(self, result):
         target = self.source[result['line'] - 1]
         c = result['column']
@@ -178,6 +205,10 @@ class FixPEP8(object):
     def fix_e262(self, result):
         self._fix_whitespace(result, r"##*", "#")
 
+    def fix_e301(self, result):
+        cr = self.newline
+        self.source[result['line'] - 1] = cr + self.source[result['line'] - 1]
+
     def fix_e302(self, result):
         add_linenum = 2 - int(result['info'].split()[-1])
         cr = self.newline * add_linenum
@@ -203,7 +234,7 @@ class FixPEP8(object):
         self.source[result['line'] - 1] = fixed_source
 
     def fix_e702(self, result):
-        # FIXME: when multiple statements.
+        # FIXME: not fixing when multiple statements.
         target = self.source[result['line'] - 1]
         f = target.split(";")
         fixed = "".join(f)
@@ -221,7 +252,7 @@ class FixPEP8(object):
         source.reverse()
         found_notblank = False
         blank_count = 0
-        for cnt, line in enumerate(source):
+        for line in source:
             if re.match("^$", line):
                 blank_count += 1
             else:
